Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(491)

Unified Diff: remoting/host/setup/oauth_helper.h

Issue 11185037: [Chromoting] Let the Linux start-host app take a redirect-URL parameter. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix Windows include. Created 8 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/setup/host_starter.cc ('k') | remoting/host/setup/oauth_helper.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/setup/oauth_helper.h
diff --git a/remoting/host/setup/oauth_helper.h b/remoting/host/setup/oauth_helper.h
index a762c2315b66e00bef9b293a6777b780a7b09821..cdb8445fea0ce3f018777e97680e20d5c85e3f3b 100644
--- a/remoting/host/setup/oauth_helper.h
+++ b/remoting/host/setup/oauth_helper.h
@@ -12,11 +12,11 @@ namespace remoting {
// Gets the OAuth scope of the host's refresh token.
std::string GetOauthScope();
-// Gets a URL at which the OAuth dance starts.
-std::string GetOauthStartUrl();
+// Gets the default redirect URL for the OAuth dance.
+std::string GetDefaultOauthRedirectUrl();
-// Gets a redirect URL for the OAuth dance.
-std::string GetOauthRedirectUrl();
+// Gets a URL at which the OAuth dance starts.
+std::string GetOauthStartUrl(const std::string& redirect_url);
// Returns the OAuth authorization code embedded in a URL, or the empty string
// if there is no such code.
@@ -25,7 +25,8 @@ std::string GetOauthRedirectUrl();
// and grant the requested permissions, (iv) monitor the URLs that the browser
// shows, passing each one to |GetOauthCodeInUrl()|, until that function returns
// a non-empty string. That string is the authorization code.
-std::string GetOauthCodeInUrl(const std::string& url);
+std::string GetOauthCodeInUrl(const std::string& url,
+ const std::string& redirect_url);
} // namespace remoting
« no previous file with comments | « remoting/host/setup/host_starter.cc ('k') | remoting/host/setup/oauth_helper.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698